SelectGridSkeleton class

Loading skeleton for SelectGridView.

Inheritance

Constructors

SelectGridSkeleton({Key? key, required int itemCount, EdgeInsetsGeometry? padding, required int crossAxisCount, double mainAxisSpacing = 0.0, double crossAxisSpacing = 0.0, double childAspectRatio = 1.0})
const

Properties

childAspectRatio double
The ratio of the cross-axis to the main-axis extent of each placeholder tile.
final
crossAxisCount int
The number of grid columns in the skeleton.
final
crossAxisSpacing double
The horizontal spacing between skeleton columns.
final
hashCode int
The hash code for this object.
no setterinherited
itemCount int
The number of placeholder tiles to render in the skeleton grid.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mainAxisSpacing double
The vertical spacing between skeleton rows.
final
padding EdgeInsetsGeometry?
The padding around the skeleton, including the title and grid.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited