padding property
The padding around the skeleton, including the title and grid.
Defaults to EdgeInsets.zero.
Implementation
final EdgeInsetsGeometry? padding;
The padding around the skeleton, including the title and grid.
Defaults to EdgeInsets.zero.
final EdgeInsetsGeometry? padding;