SelectGridTileTheme class
Theme configuration for SelectGridTile.
- Mixed-in types
- Annotations
Constructors
- SelectGridTileTheme({Color? selectedColor, Color? textColor, TextStyle? labelStyle, TextStyle? sublabelStyle, SelectGridTileVariant? variant, Color? tileColor, Color? selectedTileColor})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- labelStyle → TextStyle?
-
Overrides the default value of SelectGridTile.labelStyle.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedColor → Color?
-
Overrides the default value of SelectGridTile.selectedColor.
final
- selectedTileColor → Color?
-
Overrides the default value of SelectGridTile.selectedTileColor.
final
- sublabelStyle → TextStyle?
-
Overrides the default value of SelectGridTile.sublabelStyle.
final
- textColor → Color?
-
Overrides the default value of SelectGridTile.textColor.
final
- tileColor → Color?
-
Overrides the default value of SelectGridTile.tileColor.
final
- variant → SelectGridTileVariant?
-
Overrides the default value of SelectGridTile.variant.
final
Methods
-
copyWith(
{Color? selectedColor, Color? textColor, TextStyle? labelStyle, TextStyle? sublabelStyle, SelectGridTileVariant? variant, Color? tileColor, Color? selectedTileColor}) → SelectGridTileTheme - Returns a copy of this theme with the given fields replaced.
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
lerp(
SelectGridTileTheme? a, SelectGridTileTheme? b, double t) → SelectGridTileTheme - Linearly interpolates between two grid tile themes.
-
of(
BuildContext context) → SelectGridTileTheme