SelectSearchBarTheme class
Theme configuration for SelectSearchBar.
- Mixed-in types
- Annotations
Constructors
- SelectSearchBarTheme({EdgeInsetsGeometry? padding, EdgeInsetsGeometry? contentPadding, double? borderRadius, bool? filled, Color? fillColor, Color? enabledBorderColor, Color? focusedBorderColor, double? borderWidth, TextStyle? hintStyle, TextStyle? textStyle, Color? iconColor, double? iconSize})
-
const
Properties
- borderRadius → double?
-
Overrides the default corner radius of the text field border.
final
- borderWidth → double?
-
The width of the text field border.
final
- contentPadding → EdgeInsetsGeometry?
-
Overrides the default padding inside the text field.
final
- enabledBorderColor → Color?
-
The border color of the unfocused text field.
final
- fillColor → Color?
-
The fill color of the text field when filled is
true.final - filled → bool?
-
Whether the text field is filled with fillColor.
final
- focusedBorderColor → Color?
-
The border color of the focused text field.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hintStyle → TextStyle?
-
The text style of the hint shown when the input is empty.
final
- iconColor → Color?
-
The color of the search and clear icons.
final
- iconSize → double?
-
The size of the search and clear icons.
final
- padding → EdgeInsetsGeometry?
-
Overrides the default padding around the search bar.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle → TextStyle?
-
The text style of the input text.
final
Methods
-
copyWith(
{EdgeInsetsGeometry? padding, EdgeInsetsGeometry? contentPadding, double? borderRadius, bool? filled, Color? fillColor, Color? enabledBorderColor, Color? focusedBorderColor, double? borderWidth, TextStyle? hintStyle, TextStyle? textStyle, Color? iconColor, double? iconSize}) → SelectSearchBarTheme - Returns a copy of this theme with the given fields replaced.
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
lerp(
SelectSearchBarTheme? a, SelectSearchBarTheme? b, double t) → SelectSearchBarTheme - Linearly interpolates between two search bar themes.
-
of(
BuildContext context) → SelectSearchBarTheme