SelectWrapLayout class
Wrap of chips layout for the children of a SelectCategoryEntry.
Rendered by SelectChipBar, which handles all SelectEntry subtypes using their SelectEntry.name as the chip label.
- Inheritance
-
- Object
- SelectLayout
- SelectWrapLayout
- Implementers
Constructors
- SelectWrapLayout({double spacing = 0.0, double runSpacing = 0.0})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runSpacing → double
-
Vertical spacing between wrapped chip rows.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → double
-
Horizontal spacing between chips in the wrap.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override